==> haskell-hspec-discover-2.11.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-discover
version:              2.11.1
visibility:           public
id:                   hspec-discover-2.11.1-J9FgaXIOftcJiOZVh13TNv
key:                  hspec-discover-2.11.1-J9FgaXIOftcJiOZVh13TNv
license:              MIT
copyright:            (c) 2012-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <https://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  6edef31b1a336158c91ee30a0bbc9059
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-discover-2.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-discover-2.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-discover-2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.11.1-J9FgaXIOftcJiOZVh13TNv
depends:              base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.11.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-discover
version:              2.11.1
visibility:           public
id:                   hspec-discover-2.11.1-57xjMPpDfOGB1dqEz9o96d
key:                  hspec-discover-2.11.1-57xjMPpDfOGB1dqEz9o96d
license:              MIT
copyright:            (c) 2012-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <https://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  fffce1a846a0afc920df428adb19ac24
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-discover-2.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-discover-2.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-discover-2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.11.1-57xjMPpDfOGB1dqEz9o96d
depends:              base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
